==> evolution-debuginfo-3.18.5.2-1.tar.xz: usr/src/debug/evolution-3.18.5.2-1/mail/e-mail-enumtypes.c <==

/* Generated data (by glib-mkenums) */

#include "e-mail-enumtypes.h"
/* enumerations from "/usr/src/ports/evolution/evolution-3.18.5.2-1.i686/src/evolution-3.18.5.2/mail/e-mail-enums.h" */
#include "/usr/src/ports/evolution/evolution-3.18.5.2-1.i686/src/evolution-3.18.5.2/mail/e-mail-enums.h"

GType
e_mail_forward_style_get_type (void)
{
	static volatile gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_MAIL_FORWARD_STYLE_ATTACHED,
			  "E_MAIL_FORWARD_STYLE_ATTACHED",
			  "attached" },
			{ E_MAIL_FORWARD_STYLE_INLINE,
			  "E_MAIL_FORWARD_STYLE_INLINE",
			  "inline" },
			{ E_MAIL_FORWARD_STYLE_QUOTED,
			  "E_MAIL_FORWARD_STYLE_QUOTED",
			  "quoted" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EMailForwardStyle"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

GType
e_mail_reply_style_get_type (void)
{
	static volatile gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_MAIL_REPLY_STYLE_QUOTED,
			  "E_MAIL_REPLY_STYLE_QUOTED",
			  "quoted" },
			{ E_MAIL_REPLY_STYLE_DO_NOT_QUOTE,
			  "E_MAIL_REPLY_STYLE_DO_NOT_QUOTE",
			  "do-not-quote" },
			{ E_MAIL_REPLY_STYLE_ATTACH,
			  "E_MAIL_REPLY_STYLE_ATTACH",
			  "attach" },
			{ E_MAIL_REPLY_STYLE_OUTLOOK,
			  "E_MAIL_REPLY_STYLE_OUTLOOK",
			  "outlook" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EMailReplyStyle"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

GType
e_mail_reply_type_get_type (void)
{
	static volatile gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_MAIL_REPLY_TO_SENDER,
			  "E_MAIL_REPLY_TO_SENDER",
			  "sender" },
			{ E_MAIL_REPLY_TO_RECIPIENT,
			  "E_MAIL_REPLY_TO_RECIPIENT",
			  "recipient" },
			{ E_MAIL_REPLY_TO_FROM,
			  "E_MAIL_REPLY_TO_FROM",
			  "from" },
			{ E_MAIL_REPLY_TO_ALL,
			  "E_MAIL_REPLY_TO_ALL",
			  "all" },
			{ E_MAIL_REPLY_TO_LIST,
			  "E_MAIL_REPLY_TO_LIST",
			  "list" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EMailReplyType"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}


/* Generated data ends here */

==> evolution-debuginfo-3.20.5-1.tar.xz: usr/src/debug/evolution-3.20.5-1/mail/e-mail-enumtypes.c <==

/* Generated data (by glib-mkenums) */

#include "e-mail-enumtypes.h"
/* enumerations from "/usr/src/ports/evolution/evolution-3.20.5-1.i686/src/evolution-3.20.5/mail/e-mail-enums.h" */
#include "/usr/src/ports/evolution/evolution-3.20.5-1.i686/src/evolution-3.20.5/mail/e-mail-enums.h"

GType
e_mail_forward_style_get_type (void)
{
	static volatile gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_MAIL_FORWARD_STYLE_ATTACHED,
			  "E_MAIL_FORWARD_STYLE_ATTACHED",
			  "attached" },
			{ E_MAIL_FORWARD_STYLE_INLINE,
			  "E_MAIL_FORWARD_STYLE_INLINE",
			  "inline" },
			{ E_MAIL_FORWARD_STYLE_QUOTED,
			  "E_MAIL_FORWARD_STYLE_QUOTED",
			  "quoted" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EMailForwardStyle"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

GType
e_mail_reply_style_get_type (void)
{
	static volatile gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_MAIL_REPLY_STYLE_QUOTED,
			  "E_MAIL_REPLY_STYLE_QUOTED",
			  "quoted" },
			{ E_MAIL_REPLY_STYLE_DO_NOT_QUOTE,
			  "E_MAIL_REPLY_STYLE_DO_NOT_QUOTE",
			  "do-not-quote" },
			{ E_MAIL_REPLY_STYLE_ATTACH,
			  "E_MAIL_REPLY_STYLE_ATTACH",
			  "attach" },
			{ E_MAIL_REPLY_STYLE_OUTLOOK,
			  "E_MAIL_REPLY_STYLE_OUTLOOK",
			  "outlook" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EMailReplyStyle"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}

GType
e_mail_reply_type_get_type (void)
{
	static volatile gsize the_type__volatile = 0;

	if (g_once_init_enter (&the_type__volatile)) {
		static const GEnumValue values[] = {
			{ E_MAIL_REPLY_TO_SENDER,
			  "E_MAIL_REPLY_TO_SENDER",
			  "sender" },
			{ E_MAIL_REPLY_TO_RECIPIENT,
			  "E_MAIL_REPLY_TO_RECIPIENT",
			  "recipient" },
			{ E_MAIL_REPLY_TO_FROM,
			  "E_MAIL_REPLY_TO_FROM",
			  "from" },
			{ E_MAIL_REPLY_TO_ALL,
			  "E_MAIL_REPLY_TO_ALL",
			  "all" },
			{ E_MAIL_REPLY_TO_LIST,
			  "E_MAIL_REPLY_TO_LIST",
			  "list" },
			{ 0, NULL, NULL }
		};
		GType the_type = g_enum_register_static (
			g_intern_static_string ("EMailReplyType"),
			values);
		g_once_init_leave (&the_type__volatile, the_type);
	}
	return the_type__volatile;
}


/* Generated data ends here */
